4.16. umbra.components.factory.scriptEditor.editorStatus — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.16. umbra.components.factory.scriptEditor.editorStatus

editorStatus.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `EditorStatus` class.

Others:

## 4.16.1. Module Attributes

`umbra.components.factory.scriptEditor.editorStatus.` `LOGGER`

`umbra.components.factory.scriptEditor.editorStatus.` `UI_FILE`

## 4.16.2. Classes

class `umbra.components.factory.scriptEditor.editorStatus.` `EditorStatus`(parent, *args, **kwargs)

  Bases: `foundations.ui.common.QWidget`

  This class defines the `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` Component Interface class status bar widget.

  Parameters: | parent – Object parent. ( QObject ) *args – Arguments. ( * ) **kwargs – Keywords arguments. ( ** )

  `container`

    This method is the property for self.__container attribute.

    Returns: | self.__container. ( QObject )

  `Lines_Columns_label_defaultText`

    This method is the property for self.__Lines_Columns_label_defaultText attribute.

    Returns: | self.__Lines_Columns_label_defaultText. ( String )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »